@@ -245,27 +245,27 @@ static GnomeUIInfo menu_defaults[] = {
 	/*
 	 * The "Game" menu
 	 */
-        { GNOME_APP_UI_ITEM, N_("_New game"),
+        { GNOME_APP_UI_ITEM, N_("_New Game"),
           N_("Start a new game"),
 	  NULL, NULL, NULL,
           GNOME_APP_PIXMAP_NONE, NULL,
           GNOME_KEY_NAME_NEW_GAME,  GNOME_KEY_MOD_NEW_GAME, NULL },
-        { GNOME_APP_UI_ITEM, N_("_Pause game"),
+        { GNOME_APP_UI_ITEM, N_("_Pause Game"),
           N_("Pause the game"),
 	  NULL, NULL, NULL,
 	  GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_TIMER_STOP,
           GNOME_KEY_NAME_PAUSE_GAME,  GNOME_KEY_MOD_PAUSE_GAME, NULL },
-        { GNOME_APP_UI_ITEM, N_("_Restart game"),
+        { GNOME_APP_UI_ITEM, N_("_Restart Game"),
           N_("Restart the game"),
 	  NULL, NULL, NULL,
           GNOME_APP_PIXMAP_NONE, NULL,
           0,  0, NULL },
-        { GNOME_APP_UI_ITEM, N_("_Undo move"),
+        { GNOME_APP_UI_ITEM, N_("_Undo Move"),
           N_("Undo the last move"),
 	  NULL, NULL, NULL,
 	  GNOME_APP_PIXMAP_STOCK, GTK_STOCK_UNDO,
           GNOME_KEY_NAME_UNDO_MOVE,  GNOME_KEY_MOD_UNDO_MOVE, NULL },
-        { GNOME_APP_UI_ITEM, N_("_Redo move"),
+        { GNOME_APP_UI_ITEM, N_("_Redo Move"),
           N_("Redo the undone move"),
 	  NULL, NULL, NULL,
 	  GNOME_APP_PIXMAP_STOCK, GTK_STOCK_REDO,
@@ -281,7 +281,7 @@ static GnomeUIInfo menu_defaults[] = {
 	  NULL, NULL, NULL,
 	  GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_SCORES,
           0,  (GdkModifierType) 0, NULL },
-        { GNOME_APP_UI_ITEM, N_("_End game"),
+        { GNOME_APP_UI_ITEM, N_("_End Game"),
           N_("End the current game"),
 	  NULL, NULL, NULL,
           GNOME_APP_PIXMAP_NONE, NULL,
@@ -435,6 +435,8 @@ showing_pixmaps_changed_notify(GConfClient            *client,
                 new_setting = gconf_value_get_bool(value);
         }
 
+	GDK_THREADS_ENTER();
+
         if (new_setting && (mi->image == NULL)) {
                 GtkWidget *pixmap;
                 GnomeUIPixmapType pixmap_type;
@@ -457,6 +459,8 @@ showing_pixmaps_changed_notify(GConfClient            *client,
         } else if (!new_setting && (mi->image != NULL)) {
 		gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (mi), NULL);
         }
+
+	GDK_THREADS_LEAVE();
 }
 
 /* Note that this function is also used for toolbars, don't assume
@@ -1320,6 +1324,8 @@ menus_have_tearoff_changed_notify(GConfClient            *client,
 	if (entry->value->type != GCONF_VALUE_BOOL)
 		return;
 
+	GDK_THREADS_ENTER();
+
 	menu = GTK_WIDGET (user_data);
 	
 	if (gconf_value_get_bool (entry->value)) {
@@ -1329,7 +1335,7 @@ menus_have_tearoff_changed_notify(GConfClient            *client,
 
 		if (tearoff) {
 			/* Do nothing */
-			return;
+			goto end;
 		}
 		
 		/* Add the tearoff */
@@ -1345,13 +1351,16 @@ menus_have_tearoff_changed_notify(GConfClient            *client,
 
 		if (!tearoff) {
 			/* Do nothing */
-			return;
+			goto end;
 		}
 		
 		/* Remove the tearoff */
 		gtk_widget_destroy (tearoff);
 		g_object_set_data (G_OBJECT (menu), "gnome-app-tearoff", NULL);
 	}
+
+ end:
+	GDK_THREADS_LEAVE();
 }
 
 
@@ -1570,7 +1579,7 @@ gnome_app_create_menus_interp (GnomeApp *app, GnomeUIInfo *uiinfo,
  * function.
  *
  * Identical to gnome_app_create_menus(), except that @user_data is passed to
- * all the callback funtions when signals are emitted.
+ * all the callback functions when signals are emitted.
  **/
 
 void
@@ -2467,7 +2476,9 @@ per_app_toolbar_style_changed_notify(GConfClient            *client,
                 }
         }
 
+	GDK_THREADS_ENTER();
         gtk_toolbar_set_style(toolbar, style);
+	GDK_THREADS_LEAVE();
 }
 
 static void
@@ -2511,7 +2522,9 @@ toolbar_style_changed_notify(GConfClient            *client,
 			style = GTK_TOOLBAR_BOTH;
         }
 
+	GDK_THREADS_ENTER();
         gtk_toolbar_set_style(toolbar, style);
+	GDK_THREADS_LEAVE();
 }
 
 static void
@@ -2550,6 +2563,10 @@ global_menu_item_activated (GtkWidget *item)
 }
 
 /* Welcome to Hack City, population: gnome-app-helper */
+/* Hack into the hack for the AIX pre-compiler. It barfs when stuff gets defined twice */
+#ifdef _
+#undef _
+#endif
 #define _(x) dgettext (GETTEXT_PACKAGE, x)
 
 static void
@@ -2683,6 +2700,9 @@ create_and_popup_toolbar_menu (GdkEventButton *event)
 }
 
 /* Now leaving Hack City */
+#ifdef _
+#undef _
+#endif
 #define _(x) gettext (x)
 
 static int
