@@ -7,8 +7,9 @@ gint
 main (gint argc, gchar **argv)
 {
 	GtkWidget *window, *entry, *frame, *vbox;
+	GnomeProgram *program;
 	
-	gnome_program_init ("testentry", "1.0",
+	program = gnome_program_init ("testentry", "1.0",
 			    libgnomeui_module_info_get (),
 			    argc, argv,
 			    NULL);
@@ -37,7 +38,10 @@ main (gint argc, gchar **argv)
 	gtk_container_add (GTK_CONTAINER (window), vbox);
 	gtk_widget_show_all (window);
 
+	gtk_window_set_modal (GTK_WINDOW (window), TRUE);
+
 	gtk_main ();
+	g_object_unref (program);
 	
 	return 0;
 }
